{% extends "exoral/base.html" %}

{% block content %}
<div class="container">
  <p>
    Bevor du eine neue Frage hinzufügst, vergewissere dich, ob sie wirklich neu ist.
    Bereits vorhandenen Fragen kannst du Pluspunkte geben.
  </p>
  <p>
    Bitte füge immer nur eine neue Frage hinzu. Gib mehrere Fragen als separate neue Fragen ein.
  </p>
  <form method="post">
    {% csrf_token %}
    <div class="form-row">
      <div class="form-group col-md-2">
        <label for="datum"><strong>Datum</strong></label>
        <input type="date" class="form-control" id="datum" name="datum" value="{% now 'Y-m-d' %}" required>
      </div>
      <div class="form-group col-md-5">
        <label for="pruefer"><strong>Prüfer</strong></label>
        <input class="form-control" type="text" placeholder="{{ pruefer }}" readonly>
      </div>
      <div class="form-group col-md-5">
        <label for="testat"><strong>Testat</strong></label>
        <input class="form-control" type="text" placeholder="{{ testat }}" readonly>
      </div>
    </div>
    <div class="form-group">
      <label for="fragentext"><strong>Frage</strong></label>
      <textarea class="form-control" id="fragentext" name="text" rows=3 required></textarea>
    </div>
    <div class="form-group">
      <label for="antwort">Antwort</label>
      <textarea class="form-control" id="antwort" name="antwort" rows=3></textarea>
    </div>
    <button type="submit" class="btn btn-primary">Erstellen</button>
  </form>
</div>
{% endblock content %}
